import { TypedDocumentNode } from '@graphql-typed-document-node/core';
import { GenericSchema } from './graphql-object/schema';
import { OperationFactory } from './graphql-object/types';
import { NhostGraphqlConstructorParams, NhostGraphqlRequestConfig, NhostGraphqlRequestResponse, RemoveIndex, RequestDocument, RequestOptions, Variables } from './types';
/**
 * @alias GraphQL
 */
export declare class NhostGraphqlClient<Schema extends GenericSchema | undefined> {
    readonly _url: string;
    private accessToken;
    private adminSecret?;
    /**
     * Use `nhost.graphql.query` to run a GraphQL query from object parameters and the schema genetated with `@graphql-codegen/typescript-nhost`.
     *
     * @example
     * ```ts
     * import schema from './generated-schema'
     * const nhost = new NhostClient({ subdomain: 'xxx', region: 'yyy', schema })
     *
     * const { id, name } = await nhost.graphql.query.customer({ select: { id: true, name: true }, variables: {id: 'customer-id' } })
     * ```
     *
     * @docs https://docs.nhost.io/reference/javascript/graphql/query
     */
    query: OperationFactory<Schema, 'Query'>;
    /**
     * Use `nhost.graphql.mutation` to run a GraphQL mutation from object parameters and the schema genetated with `@graphql-codegen/typescript-nhost`.
     *
     * @example
     * ```ts
     * import schema from './generated-schema'
     * const nhost = new NhostClient({ subdomain: 'xxx', region: 'yyy', schema })
     *
     * const { id } = await nhost.graphql.mutation.insertCustomer({ select: { id: true }, variables: { name: 'Bob' } })
     * ```
     *
     * @docs https://docs.nhost.io/reference/javascript/graphql/mutation
     */
    mutation: OperationFactory<Schema, 'Mutation'>;
    constructor(params: NhostGraphqlConstructorParams<Schema>);
    /**
     * Use `nhost.graphql.request` to send a GraphQL request. For more serious GraphQL usage we recommend using a GraphQL client such as Apollo Client (https://www.apollographql.com/docs/react).
     *
     * @example
     * ```ts
     * const CUSTOMERS = gql`
     *  query {
     *   customers {
     *    id
     *    name
     *  }
     * }
     * `
     * const { data, error } = await nhost.graphql.request(CUSTOMERS)
     * ```
     *
     * @docs https://docs.nhost.io/reference/javascript/graphql/request
     */
    request<T = any, V = Variables>(document: RequestDocument | TypedDocumentNode<T, V>, ...variablesAndRequestHeaders: V extends Record<any, never> ? [variables?: V, config?: NhostGraphqlRequestConfig] : keyof RemoveIndex<V> extends never ? [variables?: V, config?: NhostGraphqlRequestConfig] : [variables: V, config?: NhostGraphqlRequestConfig]): Promise<NhostGraphqlRequestResponse<T>>;
    request<T = any, V extends Variables = Variables>(options: RequestOptions<V, T>): Promise<NhostGraphqlRequestResponse<T>>;
    /**
     * Use `nhost.graphql.httpUrl` to get the GraphQL HTTP URL.
     * @example
     * ```ts
     * const url = nhost.graphql.httpUrl;
     * ```
     *
     * @docs https://docs.nhost.io/reference/javascript/graphql/get-http-url
     */
    get httpUrl(): string;
    /**
     * Use `nhost.graphql.wsUrl` to get the GraphQL WebSocket URL.
     * @example
     * ```ts
     * const url = nhost.graphql.wsUrl;
     * ```
     *
     * @docs https://docs.nhost.io/reference/javascript/graphql/get-ws-url
     */
    get wsUrl(): string;
    /**
     * Use `nhost.graphql.url` to get the GraphQL URL.
     * @deprecated Use `nhost.graphql.httpUrl` and `nhost.graphql.wsUrl` instead.
     */
    get url(): string;
    /**
     * Use `nhost.graphql.getUrl()` to get the GraphQL URL.
     * @deprecated Use `nhost.graphql.httpUrl` and `nhost.graphql.wsUrl` instead.
     */
    getUrl(): string;
    /**
     * Use `nhost.graphql.setAccessToken` to a set an access token to be used in subsequent graphql requests. Note that if you're signin in users with `nhost.auth.signIn()` the access token will be set automatically.
     *
     * @example
     * ```ts
     * nhost.graphql.setAccessToken('some-access-token')
     * ```
     *
     * @docs https://docs.nhost.io/reference/javascript/graphql/set-access-token
     */
    setAccessToken(accessToken: string | undefined): void;
    private generateAccessTokenHeaders;
}
//# sourceMappingURL=client.d.ts.map